import { ILoggerParameters } from "./ILoggerParameters";
import { ILoggerGlobalParameters } from "./ILoggerGlobalParameters";
import { LogLevel } from "./LogLevel";
import { RecursivePartial } from "./RecursivePartial";
export declare class Logger {
    protected readonly module_name: string;
    protected readonly params: ILoggerParameters;
    /**
     * @param {Partial<ILoggerGlobalParameters>} parameters
     */
    static setGlobalParameters(parameters: RecursivePartial<ILoggerGlobalParameters>): void;
    /**
     * @returns {ILoggerGlobalParameters}
     */
    static getGlobalParameters(): ILoggerGlobalParameters;
    constructor(module_name: string, parameters?: RecursivePartial<ILoggerParameters>);
    /**
     * @param {LogLevel} log_level
     * @param {string} message
     * @param parameters
     */
    write(log_level: LogLevel, message: string, ...parameters: any[]): void;
    /**
     * @param {LogLevel} log_level
     * @returns {string}
     * @protected
     */
    protected format_log_level(log_level: LogLevel): string;
    /**
     * @param {string} module_name
     * @returns {string}
     * @protected
     */
    protected format_module_name(module_name: string): string;
    /**
     * @param {string} message
     * @param parameters
     */
    debug(message: string, ...parameters: any[]): void;
    /**
     * @param {string} message
     * @param parameters
     */
    info(message: string, ...parameters: any[]): void;
    /**
     * @param {string} message
     * @param parameters
     */
    notice(message: string, ...parameters: any[]): void;
    /**
     * @param {string} message
     * @param parameters
     */
    warn(message: string, ...parameters: any[]): void;
    /**
     * @param {string} message
     * @param parameters
     */
    warning(message: string, ...parameters: any[]): void;
    /**
     * @param {string} message
     * @param parameters
     */
    error(message: string, ...parameters: any[]): void;
    /**
     * @param {string} message
     * @param parameters
     */
    critical(message: string, ...parameters: any[]): void;
}
